@@ -804,7 +804,7 @@ static struct PreDefProp propNames[] = {
     { VCEventProp, 0, 0, PD_BEGIN },
     { VCEWorldProp, 0, 0, 0 },
     { VCExNumProp, 0, 0, 0 },
-    { VCExDateProp, 0, 0, 0 },
+    { VCExpDateProp, 0, 0, 0 },
     { VCExpectProp, 0, 0, 0 },
     { VCExtAddressProp, 0, 0, 0 },
     { VCFamilyNameProp, 0, 0, 0 },
@@ -1405,6 +1405,9 @@ wchar_t* fakeUnicode(const char *ps, int *bytes)
 unsigned int uStrLen(const wchar_t *u)
 {
     int i = 0;
+    if(u == NULL)
+      return 0;
+
     while (*u != (wchar_t)0) { u++; i++; }
     return i;
 }
@@ -1412,7 +1415,12 @@ unsigned int uStrLen(const wchar_t *u)
 char* fakeCString(const wchar_t *u)
 {
     char *s, *t;
-    unsigned int len = uStrLen(u) + 1;
+    unsigned int len;
+
+    if(u == NULL)
+      return NULL;
+
+    len = uStrLen(u) + 1;
     t = s = (char*)malloc(len+1);
     while (*u) {
 	if (*u == (wchar_t)0x2028)
