@@ -57,8 +57,7 @@ extern const uchar eTextMap[16];
 
 inline bool isOfSet( const uchar map[16], unsigned char ch )
 {
-  Q_ASSERT( ch < 128 );
-  return map[ ch/8 ] & 0x80 >> ch%8;
+  return ( ch < 128 ) && ( map[ ch/8 ] & 0x80 >> ch%8 );
 }
 inline bool isSpecial( char ch )
 {
@@ -98,6 +97,14 @@ KMIME_EXPORT extern QString decodeRFC2047String(
   const QByteArray &src, QByteArray &usedCS, const QByteArray &defaultCS = QByteArray(),
   bool forceCS = false );
 
+/** Decode string @p src according to RFC2047 (ie. the
+    =?charset?[qb]?encoded?= construct).
+
+    @param src       source string.
+    @return the decoded string.
+*/
+KMIME_EXPORT extern QString decodeRFC2047String( const QByteArray &src );
+
 /**
   Encodes string @p src according to RFC2047 using charset @p charset.
 
@@ -152,6 +159,20 @@ KMIME_EXPORT extern QByteArray unfoldHeader( const QByteArray &header );
 KMIME_EXPORT extern QByteArray extractHeader( const QByteArray &src,
                                  const QByteArray &name );
 
+/**
+  Tries to extract the headers with name @p name from the string
+  @p src, unfolding it if necessary.
+
+  @param src  the source string.
+  @param name the name of the header to search for.
+
+  @return all instances of the header @p name in @p src
+
+  @since 4.2
+*/
+KMIME_EXPORT extern QList<QByteArray> extractHeaders( const QByteArray &src,
+                                 const QByteArray &name );
+
 /**
   Converts all occurrences of "\r\n" (CRLF) in @p s to "\n" (LF).
 
