@@ -21,6 +21,10 @@
 #include "identity.h"
 #include "signature.h"
 
+#include <kdeversion.h>
+#if KDE_IS_VERSION( 4, 1, 67 )
+#include <sonnet/globals.h>
+#endif
 #include <kdebug.h>
 #include <klocale.h>
 #include <kmessagebox.h>
@@ -55,6 +59,9 @@ Identity::Identity( const QString &id, const QString &fullName,
   setProperty( s_email, emailAddr );
   setProperty( s_organization, organization );
   setProperty( s_replyto, replyToAddr );
+#if KDE_IS_VERSION( 4, 1, 67 )
+  setDictionary( Sonnet::defaultLanguageName() );
+#endif
 }
 
 Identity::~Identity()
@@ -74,6 +81,14 @@ bool Identity::isNull() const
   QHash<QString, QVariant>::const_iterator i = mPropertiesMap.constBegin();
   while ( i != mPropertiesMap.constEnd() ) {
 
+#if KDE_IS_VERSION( 4, 1, 67 )
+    // Take into account that the dictionary for a null identity is not empty
+    if ( i.key() == s_dict && dictionary() == Sonnet::defaultLanguageName() ) {
+      ++i;
+      continue;
+    }
+#endif
+
     // The uoid is 0 by default, so ignore this
     if ( !( i.key() == s_uoid && i.value().toUInt() == 0 ) ) {
       if ( !i.value().isNull() ||
