@@ -22,7 +22,6 @@
   This file is part of the KDEPIM Utilities library and provides
   static methods for email address validation.
 
-
   @author Matt Douhan \<matt@fruitsalad.org\>
  */
 
@@ -31,6 +30,7 @@
 #include <kdebug.h>
 #include <klocale.h>
 #include <kurl.h>
+#include <kmime_util.h>
 
 #include <QtCore/QRegExp>
 #include <QtCore/QByteArray>
@@ -78,7 +78,6 @@ QStringList KPIMUtils::splitAddressList( const QString &aStr )
         if ( commentlevel > 0 ) {
           commentlevel--;
         } else {
-          kDebug(5321) << "Error in address splitting: Unmatched ')'";
           return list;
         }
       }
@@ -103,9 +102,6 @@ QStringList KPIMUtils::splitAddressList( const QString &aStr )
     if ( !addr.isEmpty() ) {
       list += addr.simplified();
     }
-  } else {
-    kDebug(5321) << "Error in address splitting:"
-                 << "Unexpected end of address list";
   }
 
   return list;
@@ -119,8 +115,7 @@ KPIMUtils::EmailParseResult splitAddressInternal( const QByteArray  address,
                                                   QByteArray &comment,
                                                   bool allowMultipleAddresses )
 {
-  //  kDebug(5321) << "KMMessage::splitAddress(" << address << ")";
-
+  //  kDebug() << "address";
   displayName = "";
   addrSpec = "";
   comment = "";
@@ -275,9 +270,9 @@ KPIMUtils::EmailParseResult splitAddressInternal( const QByteArray  address,
     }
   }
   /*
-    kDebug(5321) << "display-name : \"" << displayName << "\"";
-    kDebug(5321) << "comment      : \"" << comment << "\"";
-    kDebug(5321) << "addr-spec    : \"" << addrSpec << "\"";
+    kDebug() << "display-name : \"" << displayName << "\"";
+    kDebug() << "comment      : \"" << comment << "\"";
+    kDebug() << "addr-spec    : \"" << addrSpec << "\"";
   */
   return AddressOk;
 }
@@ -510,7 +505,7 @@ KPIMUtils::EmailParseResult KPIMUtils::isValidAddressList( const QString &aStr,
     return AddressEmpty;
   }
 
-  QStringList list = splitAddressList( aStr );
+  const QStringList list = splitAddressList( aStr );
 
   QStringList::const_iterator it = list.begin();
   EmailParseResult errorCode = AddressOk;
@@ -647,9 +642,11 @@ QByteArray KPIMUtils::extractEmailAddress( const QByteArray &address )
                           false/* don't allow multiple addresses */ );
   if ( result != AddressOk ) {
     addrSpec = QByteArray();
-    kDebug(5321) // << "\n"
-      << "Input: aStr\nError:"
-      << emailParseResultToString( result );
+    if ( result != AddressEmpty ) {
+      kDebug()
+        << "Input: aStr\nError:"
+        << emailParseResultToString( result );
+    }
   }
 
   return addrSpec;
@@ -670,9 +667,11 @@ QByteArray KPIMUtils::firstEmailAddress( const QByteArray &addresses )
                           true/* allow multiple addresses */ );
   if ( result != AddressOk ) {
     addrSpec = QByteArray();
-    kDebug(5321) // << "\n"
-      << "Input: aStr\nError:"
-      << emailParseResultToString( result );
+    if ( result != AddressEmpty ) {
+      kDebug()
+        << "Input: aStr\nError:"
+        << emailParseResultToString( result );
+    }
   }
 
   return addrSpec;
@@ -704,14 +703,19 @@ bool KPIMUtils::extractEmailAddressAndName( const QString &aStr,
   // skipping all '@' inside "(...)" comments:
   while ( i < len ) {
     c = aStr[i];
-    if( '(' == c ) commentstack++;
-    if( ')' == c ) commentstack--;
+    if ( '(' == c ) {
+      commentstack++;
+    }
+    if ( ')' == c ) {
+      commentstack--;
+    }
     bInComment = commentstack != 0;
-    if( '"' == c && !bInComment )
-        bInQuotesOutsideOfEmail = !bInQuotesOutsideOfEmail;
+    if ( '"' == c && !bInComment ) {
+      bInQuotesOutsideOfEmail = !bInQuotesOutsideOfEmail;
+    }
 
     if( !bInComment && !bInQuotesOutsideOfEmail ) {
-      if( '@' == c ){
+      if ( '@' == c ) {
         iAd = i;
         break; // found it
       }
@@ -894,7 +898,11 @@ QString KPIMUtils::normalizedAddress( const QString &displayName,
   if ( displayName.isEmpty() && comment.isEmpty() ) {
     return addrSpec;
   } else if ( comment.isEmpty() ) {
-    return displayName + " <" + addrSpec + '>';
+    if ( !displayName.startsWith( '\"' ) ) {
+      return quoteNameIfNecessary( displayName ) + " <" + addrSpec + '>';
+    } else {
+      return displayName + " <" + addrSpec + '>';
+    }
   } else if ( displayName.isEmpty() ) {
     QString commentStr = comment;
     return quoteNameIfNecessary( commentStr ) + " <" + addrSpec + '>';
@@ -938,8 +946,7 @@ QString KPIMUtils::toIdn( const QString &addrSpec )
 //-----------------------------------------------------------------------------
 QString KPIMUtils::normalizeAddressesAndDecodeIdn( const QString &str )
 {
-  //  kDebug(5321) << "KPIMUtils::normalizeAddressesAndDecodeIDNs( \""
-  //                << str << "\" )";
+  //  kDebug() << str;
   if ( str.isEmpty() ) {
     return str;
   }
@@ -956,19 +963,20 @@ QString KPIMUtils::normalizeAddressesAndDecodeIdn( const QString &str )
       if ( splitAddress( (*it).toUtf8(),
                          displayName, addrSpec, comment ) == AddressOk ) {
 
-        normalizedAddressList <<
-          normalizedAddress( QString::fromUtf8( displayName ),
-                             fromIdn( QString::fromUtf8( addrSpec ) ),
-                             QString::fromUtf8( comment ) );
-      } else {
-        kDebug(5321) << "splitting address failed:" << *it;
+        displayName = KMime::decodeRFC2047String(displayName).toUtf8();
+        comment = KMime::decodeRFC2047String(comment).toUtf8();
+
+        normalizedAddressList
+          << normalizedAddress( QString::fromUtf8( displayName ),
+                                fromIdn( QString::fromUtf8( addrSpec ) ),
+                                QString::fromUtf8( comment ) );
       }
     }
   }
   /*
-    kDebug(5321) << "normalizedAddressList: \""
-    << normalizedAddressList.join( ", " )
-    << "\"";
+    kDebug() << "normalizedAddressList: \""
+             << normalizedAddressList.join( ", " )
+             << "\"";
   */
   return normalizedAddressList.join( ", " );
 }
@@ -976,8 +984,7 @@ QString KPIMUtils::normalizeAddressesAndDecodeIdn( const QString &str )
 //-----------------------------------------------------------------------------
 QString KPIMUtils::normalizeAddressesAndEncodeIdn( const QString &str )
 {
-  //kDebug(5321) << "KPIMUtils::normalizeAddressesAndEncodeIDNs( \""
-  //              << str << "\" )";
+  //kDebug() << str;
   if ( str.isEmpty() ) {
     return str;
   }
@@ -994,20 +1001,17 @@ QString KPIMUtils::normalizeAddressesAndEncodeIdn( const QString &str )
       if ( splitAddress( (*it).toUtf8(),
                          displayName, addrSpec, comment ) == AddressOk ) {
 
-        normalizedAddressList <<
-          normalizedAddress( QString::fromUtf8( displayName ),
-                             toIdn( QString::fromUtf8( addrSpec ) ),
-                             QString::fromUtf8( comment ) );
-      } else {
-        kDebug(5321) << "splitting address failed:" << *it;
+        normalizedAddressList << normalizedAddress( QString::fromUtf8( displayName ),
+                                                    toIdn( QString::fromUtf8( addrSpec ) ),
+                                                    QString::fromUtf8( comment ) );
       }
     }
   }
 
   /*
-    kDebug(5321) << "normalizedAddressList: \""
-    << normalizedAddressList.join( ", " )
-    << "\"";
+    kDebug() << "normalizedAddressList: \""
+             << normalizedAddressList.join( ", " )
+             << "\"";
   */
   return normalizedAddressList.join( ", " );
 }
