@@ -1,7 +1,7 @@
 /*
  * This file is part of the syndication library
  *
- * Copyright (C) 2006 Frank Osterfeld <frank.osterfeld@kdemail.net>
+ * Copyright (C) 2006 Frank Osterfeld <osterfeld@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -19,11 +19,10 @@
  * Boston, MA 02110-1301, USA.
  *
  */
-
+#include "entry.h"
 #include "category.h"
 #include "constants.h"
 #include "content.h"
-#include "entry.h"
 #include "link.h"
 #include "person.h"
 #include "source.h"
@@ -32,9 +31,9 @@
 #include <specificitemvisitor.h>
 #include <tools.h>
 
-#include <QDomElement>
-#include <QList>
-#include <QString>
+#include <QtXml/QDomElement>
+#include <QtCore/QList>
+#include <QtCore/QString>
 
 namespace Syndication {
 namespace Atom {
@@ -54,8 +53,8 @@ QList<Person> Entry::authors() const
                                 QString::fromUtf8("author"));
     QList<Person> list;
                                        
-    QList<QDomElement>::ConstIterator it = a.begin();
-    QList<QDomElement>::ConstIterator end = a.end();
+    QList<QDomElement>::ConstIterator it = a.constBegin();
+    QList<QDomElement>::ConstIterator end = a.constEnd();
     
     
     for ( ; it != end; ++it)
@@ -73,8 +72,8 @@ QList<Person> Entry::contributors() const
                                 QString::fromUtf8("contributor"));
     QList<Person> list;
                                        
-    QList<QDomElement>::ConstIterator it = a.begin();
-    QList<QDomElement>::ConstIterator end = a.end();
+    QList<QDomElement>::ConstIterator it = a.constBegin();
+    QList<QDomElement>::ConstIterator end = a.constEnd();
     
     
     for ( ; it != end; ++it)
@@ -92,8 +91,8 @@ QList<Category> Entry::categories() const
                                 QString::fromUtf8("category"));
     QList<Category> list;
     
-    QList<QDomElement>::ConstIterator it = a.begin();
-    QList<QDomElement>::ConstIterator end = a.end();
+    QList<QDomElement>::ConstIterator it = a.constBegin();
+    QList<QDomElement>::ConstIterator end = a.constEnd();
 
 
     for ( ; it != end; ++it)
@@ -118,8 +117,8 @@ QList<Link> Entry::links() const
                                 QString::fromUtf8("link"));
     QList<Link> list;
     
-    QList<QDomElement>::ConstIterator it = a.begin();
-    QList<QDomElement>::ConstIterator end = a.end();
+    QList<QDomElement>::ConstIterator it = a.constBegin();
+    QList<QDomElement>::ConstIterator end = a.constEnd();
 
 
     for ( ; it != end; ++it)
@@ -230,27 +229,27 @@ QString Entry::debugInfo() const
         info += "published: #" + dpublished + "#\n";
     
     QList<Link> dlinks = links();
-    QList<Link>::ConstIterator endlinks = dlinks.end();
-    for (QList<Link>::ConstIterator it = dlinks.begin(); it != endlinks; ++it)
+    QList<Link>::ConstIterator endlinks = dlinks.constEnd();
+    for (QList<Link>::ConstIterator it = dlinks.constBegin(); it != endlinks; ++it)
         info += (*it).debugInfo();
     
     QList<Category> dcats = categories();
-    QList<Category>::ConstIterator endcats = dcats.end();
-    for (QList<Category>::ConstIterator it = dcats.begin(); it != endcats; ++it)
+    QList<Category>::ConstIterator endcats = dcats.constEnd();
+    for (QList<Category>::ConstIterator it = dcats.constBegin(); it != endcats; ++it)
         info += (*it).debugInfo();
 
     info += "### Authors: ###################\n";
     
     QList<Person> dauthors = authors();
-    QList<Person>::ConstIterator endauthors = dauthors.end();
-    for (QList<Person>::ConstIterator it = dauthors.begin(); it != endauthors; ++it)
+    QList<Person>::ConstIterator endauthors = dauthors.constEnd();
+    for (QList<Person>::ConstIterator it = dauthors.constBegin(); it != endauthors; ++it)
         info += (*it).debugInfo();
 
     info += "### Contributors: ###################\n";
     
     QList<Person> dcontri = contributors();
-    QList<Person>::ConstIterator endcontri = dcontri.end();
-    for (QList<Person>::ConstIterator it = dcontri.begin(); it != endcontri; ++it)
+    QList<Person>::ConstIterator endcontri = dcontri.constEnd();
+    for (QList<Person>::ConstIterator it = dcontri.constBegin(); it != endcontri; ++it)
         info += (*it).debugInfo();
     
     if (!source().isNull())
